==> zio-aws-sagemaker_2.12-5.17.112.1-sources.jar: zio/aws/sagemaker/model/AutoMLOutputDataConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.{S3Uri, KmsKeyId}
import scala.jdk.CollectionConverters._
final case class AutoMLOutputDataConfig(
    kmsKeyId: Option[KmsKeyId] = None,
    s3OutputPath: S3Uri
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig = {
    import AutoMLOutputDataConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
      .builder()
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .s3OutputPath(S3Uri.unwrap(s3OutputPath): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AutoMLOutputDataConfig.ReadOnly =
    zio.aws.sagemaker.model.AutoMLOutputDataConfig.wrap(buildAwsValue())
}
object AutoMLOutputDataConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AutoMLOutputDataConfig =
      zio.aws.sagemaker.model
        .AutoMLOutputDataConfig(kmsKeyId.map(value => value), s3OutputPath)
    def kmsKeyId: Option[KmsKeyId]
    def s3OutputPath: S3Uri
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
    def getS3OutputPath: ZIO[Any, Nothing, S3Uri] = ZIO.succeed(s3OutputPath)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
  ) extends zio.aws.sagemaker.model.AutoMLOutputDataConfig.ReadOnly {
    override val kmsKeyId: Option[KmsKeyId] = scala
      .Option(impl.kmsKeyId())
      .map(value => zio.aws.sagemaker.model.primitives.KmsKeyId(value))
    override val s3OutputPath: S3Uri =
      zio.aws.sagemaker.model.primitives.S3Uri(impl.s3OutputPath())
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
  ): zio.aws.sagemaker.model.AutoMLOutputDataConfig.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_2.13-5.17.164.1-sources.jar: zio/aws/sagemaker/model/AutoMLOutputDataConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{S3Uri, KmsKeyId}
import scala.jdk.CollectionConverters._
final case class AutoMLOutputDataConfig(
    kmsKeyId: Optional[KmsKeyId] = Optional.Absent,
    s3OutputPath: S3Uri
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig = {
    import AutoMLOutputDataConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
      .builder()
      .optionallyWith(
        kmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.kmsKeyId)
      .s3OutputPath(S3Uri.unwrap(s3OutputPath): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AutoMLOutputDataConfig.ReadOnly =
    zio.aws.sagemaker.model.AutoMLOutputDataConfig.wrap(buildAwsValue())
}
object AutoMLOutputDataConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AutoMLOutputDataConfig =
      zio.aws.sagemaker.model
        .AutoMLOutputDataConfig(kmsKeyId.map(value => value), s3OutputPath)
    def kmsKeyId: Optional[KmsKeyId]
    def s3OutputPath: S3Uri
    def getKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("kmsKeyId", kmsKeyId)
    def getS3OutputPath: ZIO[Any, Nothing, S3Uri] = ZIO.succeed(s3OutputPath)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
  ) extends zio.aws.sagemaker.model.AutoMLOutputDataConfig.ReadOnly {
    override val kmsKeyId: Optional[KmsKeyId] = zio.aws.core.internal
      .optionalFromNullable(impl.kmsKeyId())
      .map(value => zio.aws.sagemaker.model.primitives.KmsKeyId(value))
    override val s3OutputPath: S3Uri =
      zio.aws.sagemaker.model.primitives.S3Uri(impl.s3OutputPath())
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AutoMLOutputDataConfig
  ): zio.aws.sagemaker.model.AutoMLOutputDataConfig.ReadOnly = new Wrapper(impl)
}
